@@ -33,9 +33,9 @@
  */
 
 #include <stdio.h>
+#include <gnome.h>
 #include <libxml/parser.h>
 #include <libxml/catalog.h>
-#include "config.h"
 #include "mlview-app.h"
 
 
@@ -46,13 +46,13 @@ int
 main (int argc, char **argv)
 {
         GnomeProgram *mlview_program = NULL;
-        GnomeApp *mlview_application = NULL;
+        MlViewApp *mlview_application = NULL;
 
         gchar **args = NULL;
         poptContext popt_context = NULL;
-        GValue popt_context_value = { 0, };
-        gboolean show_version = FALSE,
-                show_info = FALSE;
+        gboolean show_version = FALSE, show_info = FALSE;
+        gchar* associated_dtd = NULL;
+
         struct poptOption cmd_options_table[] = {
                 {
                  "version",
@@ -72,26 +72,34 @@ main (int argc, char **argv)
                  N_
                  ("Prints some information about gnome-mlview"),
                  NULL},
+                {
+                 "dtd",
+                 'd',
+                 POPT_ARG_STRING,
+                 &associated_dtd,
+                 0,
+                 N_
+                 ("Associates DTD with the XML documents on the commandline"),
+                 NULL},
                 {0}
         };
         /*init underlaying facilities */
         mlview_utils_init ();
 
         /*init gnome */
-        mlview_program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+        mlview_program = gnome_program_init (PACKAGE, VERSION, 
+                                             LIBGNOMEUI_MODULE,
                                              argc, argv,
                                              GNOME_PARAM_POPT_TABLE, cmd_options_table,
                                              GNOME_PARAM_APP_DATADIR, DATADIR, 
                                              GNOME_PARAM_NONE);
         
         gnome_program_parse_args (mlview_program);
-
-        g_value_init (&popt_context_value, G_TYPE_POINTER);
-        g_object_get_property (G_OBJECT (mlview_program), GNOME_PARAM_POPT_CONTEXT,
-                               &popt_context_value);
-        popt_context = g_value_peek_pointer (&popt_context_value);
-        g_value_unset (&popt_context_value);
-
+        g_object_get (G_OBJECT (mlview_program),
+                      GNOME_PARAM_POPT_CONTEXT,
+                      &popt_context, 
+                      NULL);
+        g_return_val_if_fail (popt_context, -1) ;
         /*Then, parse the non option command arguments */
         args = (gchar **) poptGetArgs (popt_context);
 
@@ -102,13 +110,18 @@ main (int argc, char **argv)
         }
 
         if (show_info == TRUE) {
-                g_print ("%s\n", _("No usefull info yest"));
+                g_print ("%s\n", _("No useful info yet"));
                 poptFreeContext (popt_context);
                 return 0;
         }
 
+        if (associated_dtd != NULL)
+        {
+                g_print ("DTD: %s\n", associated_dtd);
+        }
+
         /*instanciate an mlview application */
-        mlview_application = mlview_app_new (PACKAGE);
+        mlview_application = mlview_app_new ((guchar*)PACKAGE);
 
         if (args) {
                 /*
@@ -123,9 +136,10 @@ main (int argc, char **argv)
                         int i;
 
                         for (i = 0; args[i] != NULL; i++) {
-                                mlview_editor_load_xml_file
+                                mlview_editor_load_xml_file_with_dtd
                                         (mlview_editor,
-                                         (gchar *) args[i]);
+                                         (gchar *) args[i],
+                                         associated_dtd);
                         }
                 }
         }
@@ -133,7 +147,6 @@ main (int argc, char **argv)
         poptFreeContext (popt_context);
 
         gtk_main ();
-
         mlview_utils_cleanup ();
 
         return 0;
