@@ -25,10 +25,12 @@
  */
 
 #include <string.h>
+#include <libxml/hash.h>
 #include <libxml/parser.h>
 #include "mlview-attrs-editor.h"
 #include "mlview-attribute-picker.h"
 #include "mlview-marshal.h"
+#include <gdk/gdkkeysyms.h>
 
 /**
  *@file
@@ -148,6 +150,11 @@ xml_doc_node_attribute_added_cb (MlViewXMLDocument *a_this,
                                  xmlAttr *a_attr,
                                  MlViewAttrsEditor *a_editor) ;
 
+static gboolean
+tree_key_press_cb (GtkTreeView *a_tree,
+             GdkEventKey *a_event,
+             MlViewAttrsEditor *a_this);
+
 /*
  *Mandatory private functions to comply with the gtk object
  *framework. go to http://www.gtk.org/tutorial/sec-theanatomyofawidget.html
@@ -256,6 +263,11 @@ mlview_attrs_editor_construct (MlViewAttrsEditor *a_this,
                                (PRIVATE (a_this)->model)) ;
         g_return_if_fail (PRIVATE (a_this)->attrs_view) ;
 
+        g_signal_connect (G_OBJECT (PRIVATE (a_this)->attrs_view),
+                         "key_press_event",
+                          G_CALLBACK (tree_key_press_cb),
+                          a_this) ;        
+
         selection = gtk_tree_view_get_selection
                 (PRIVATE (a_this)->attrs_view) ;
         g_return_if_fail (selection) ;
@@ -405,10 +417,6 @@ mlview_attrs_editor_add_attribute_to_node_interactive (MlViewAttrsEditor * a_thi
                 (PRIVATE (a_this)->attribute_picker, a_node);
         while (loop) {
                 xmlAttributeType attr_type;
-                mlview_app_context_set_window_icon
-                        (PRIVATE (a_this)->app_context,
-                         GTK_WINDOW 
-                         (PRIVATE (a_this)->attribute_picker));
                 button = gtk_dialog_run
                         (GTK_DIALOG
                          (PRIVATE (a_this)->attribute_picker));
@@ -733,7 +741,8 @@ attr_name_cell_edited_cb (GtkCellRendererText *a_renderer,
         GtkTreeIter iter = {0} ;
         guchar *attr_value = NULL, *attr_name = NULL ;
         GtkTreeModel *model = NULL ;
-        xmlAttr *attr = NULL ;
+        xmlAttr *attr = NULL, *attr2 = NULL ;
+        const gchar * err_msg = "This node already has an attribute with the same name !" ;
 
         g_return_if_fail (a_cell_path && a_attr_name
                           && a_editor && MLVIEW_IS_ATTRS_EDITOR (a_editor)
@@ -758,6 +767,17 @@ attr_name_cell_edited_cb (GtkCellRendererText *a_renderer,
                  */
                 if (a_attr_name
                     && strcmp (a_attr_name, "")) {
+                        if (xmlHasProp (PRIVATE (a_editor)->current_xml_node,
+                                        a_attr_name)) {
+                                /*
+                                 *this node already has an attibute with
+                                 *the same name.
+                                 */
+                                mlview_app_context_error 
+                                        (PRIVATE (a_editor)->app_context,
+                                         _(err_msg)) ;
+                                return ;
+                        }
                         mlview_xml_document_set_attribute
                                 (PRIVATE (a_editor)->mlview_xml_doc,
                                  PRIVATE (a_editor)->current_xml_node,
@@ -768,6 +788,13 @@ attr_name_cell_edited_cb (GtkCellRendererText *a_renderer,
                                     HIDDEN_XML_ATTR_COLUMN, &attr,
                                     -1) ;
                 g_return_if_fail (attr) ;
+                attr2 = xmlHasProp (attr->parent, a_attr_name) ;
+                if (attr2 != attr) {
+                        /*an attribute with the same name already exist !*/
+                        mlview_app_context_error (PRIVATE (a_editor)->app_context,
+                                                  _(err_msg)) ;
+                        return ;
+                }
                 if (a_attr_name
                     && strcmp (a_attr_name, "")
                     && strcmp (a_attr_name, attr_name)) {
@@ -824,6 +851,34 @@ attr_value_cell_edited_cb (GtkCellRendererText *a_renderer,
         }
 }
 
+
+/**
+ *callback for key_press_event in the attributes treeview
+ *remove the selected attribute if DEL key is pressed
+ */
+
+static gboolean
+tree_key_press_cb (GtkTreeView *a_tree,
+             GdkEventKey *a_event,
+             MlViewAttrsEditor *a_this)
+{
+        enum MlViewStatus status = MLVIEW_OK ;
+        GtkTreeIter iter = {0} ;
+        
+        g_return_val_if_fail (a_tree && a_event && a_this, FALSE) ;
+        
+        status = mlview_attrs_editor_get_cur_sel_iter(a_this, &iter);
+        if(status != MLVIEW_OK)
+                return FALSE ;
+
+        if (a_event->keyval == GDK_Delete) {
+                mlview_attrs_editor_remove_attribute (a_this, &iter) ;	  
+                return TRUE ;
+        }
+                      
+        return FALSE ;
+}
+
 /************************
  *public methods        *
  ************************/
@@ -1593,7 +1648,10 @@ mlview_attrs_editor_update_attribute (MlViewAttrsEditor *a_this,
 
         status = mlview_attrs_editor_get_row_ref_from_xml_attr 
                 (a_this, a_attr, &row_ref) ;
+
         g_return_val_if_fail (status == MLVIEW_OK, status) ;
+
+        
         if (!row_ref) {
                 status = mlview_attrs_editor_insert_attribute
                         (a_this, &iter, -1 , a_attr) ;
