@@ -60,6 +60,16 @@ enum MLVIEW_XML_DOC_VIEW_TYPE {
         MLVIEW_XML_DOC_TREE_VIEW
 };
 
+typedef GtkWidget * (*ViewConstructor) (MlViewXMLDocument *a_doc,
+                                        gchar *a_view_name,
+                                        MlViewAppContext *a_context) ;
+
+struct MlViewViewDesc {
+        gchar *view_type_name ;
+        gchar *view_description ;
+        ViewConstructor view_constructor ;        
+} ;
+
 /**
  *The data members of the class
  *#MlViewEditor.
@@ -87,8 +97,15 @@ struct _MlViewEditorClass {
          /**
           *"document-changed" signal's default handler.
           */
-        void (*document_changed) (MlViewEditor * editor,
-                                  gpointer data);
+        void (*document_changed) (MlViewEditor * a_editor,
+                                  gpointer a_data);
+
+        void (*last_view_removed)  (MlViewEditor *a_editor,
+                                   gpointer a_data) ;
+
+        void (*first_view_added) (MlViewEditor *a_editor,
+                                  MlViewIView *a_this,
+                                  gpointer a_data) ;
 };
 
 
@@ -98,8 +115,7 @@ GtkWidget *mlview_editor_new (const guchar * a_title,
                               MlViewAppContext * a_context);
 
 MlViewIView * mlview_editor_create_new_view_on_document (MlViewEditor *a_editor,
-                                                         MlViewXMLDocument *a_xml_doc, 
-                                                         enum MLVIEW_XML_DOC_VIEW_TYPE a_view_type) ;
+                                                         MlViewXMLDocument *a_xml_doc) ;
 
 MlViewIView * mlview_editor_create_new_view_on_current_document_interactive  (MlViewEditor * a_editor);
 
@@ -119,6 +135,10 @@ GList *mlview_editor_get_list_open_doc (MlViewEditor * a_this);
 void mlview_editor_load_xml_file (MlViewEditor * a_editor,
                                   gchar * a_file_path);
 
+void mlview_editor_load_xml_file_with_dtd (MlViewEditor * a_this,
+                                           gchar * a_file_path,
+                                           gchar * a_dtd_path);
+
 void mlview_editor_open_local_xml_document_interactive (MlViewEditor * editor);
 
 
@@ -163,7 +183,7 @@ void mlview_editor_create_new_xml_document (MlViewEditor * a_editor);
 
 void mlview_editor_close_xml_document_interactive (MlViewEditor * a_editor);
 
-void mlview_editor_close_all_xml_documents_interactive (MlViewEditor * a_editor);
+gboolean mlview_editor_close_all_xml_documents_interactive (MlViewEditor * a_editor);
 
 void mlview_editor_paste_node_as_prev_sibling (MlViewEditor * a_editor);
 
@@ -192,5 +212,11 @@ enum MlViewStatus mlview_editor_execute_action (MlViewEditor *a_this,
 
 void mlview_editor_xslt_transform_document_interactive (MlViewEditor *a_this);
 
+struct MlViewViewDesc * mlview_editor_peek_editing_view_descriptor (gchar *a_view_type_name) ;
+
+guint mlview_editor_get_number_of_view_desc (void) ;
+
+struct MlViewViewDesc * mlview_editor_get_view_descriptor_at (guint a_offset) ;
+
 G_END_DECLS
 #endif /*__MLVIEW_EDITOR_H__*/
