@@ -40,7 +40,7 @@ static gboolean gv_on_going_validation = TRUE;
 
 /*the data structure of the private part of MlViewNodeType*/
 struct _MlViewNodeTypePickerPrivate {
-        guint selected_node_type;
+        NodeTypeDefinition *selected_node_type_def;
 
         /*a combo box that lets the user choose a type of node */
         GtkCombo *node_types_combo;
@@ -77,13 +77,6 @@ struct _MlViewNodeTypePickerPrivate {
 };
 
 
-/*The data structure to define xml node types*/
-typedef struct _NodeTypeDefinition NodeTypeDefinition;
-struct _NodeTypeDefinition {
-        const char *node_type_name;
-        guint node_type_id;
-};
-
 #define PRIVATE(node_type_picker) (node_type_picker->priv)
 static const int NO_SELECTED_NODE_TYPE = -1;
 
@@ -93,19 +86,39 @@ static const int NO_SELECTED_NODE_TYPE = -1;
  *The types come from the file libxml/tree.h of 
  *Daniel Veillard's libxml2
  *=============================================*/
-static
-NodeTypeDefinition gv_xml_node_types[] = {
-        {"ELEMENT NODE", XML_ELEMENT_NODE}, /*0 */
-        {"TEXT NODE", XML_TEXT_NODE}, /*1 */
-        {"PI NODE", XML_PI_NODE}, /*2 */
-        {"COMMENT NODE", XML_COMMENT_NODE}, /*3 */
+static NodeTypeDefinition gv_xml_node_types[] = {
+        {"ELEMENT NODE", XML_ELEMENT_NODE, 0}, /*0 */
+        {"TEXT NODE", XML_TEXT_NODE, 0}, /*1 */
+        {"PI NODE", XML_PI_NODE, 0}, /*2 */
+        {"COMMENT NODE", XML_COMMENT_NODE, 0}, /*3 */
+        {"CDATA SECTION NODE", XML_CDATA_SECTION_NODE, 0},
+        {"XML INTERNAL GENERAL ENTITY DECL",XML_ENTITY_DECL,
+         XML_INTERNAL_GENERAL_ENTITY},
+        {"XML EXTERNAL GENERAL PARSED ENTITY DECL",XML_ENTITY_DECL,
+         XML_EXTERNAL_GENERAL_PARSED_ENTITY},
+        {"XML EXTERNAL GENERAL UNPARSED ENTITY DECL",XML_ENTITY_DECL,
+         XML_EXTERNAL_GENERAL_UNPARSED_ENTITY},
+        {"XML INTERNAL PARAMETER ENTITY DECL",XML_ENTITY_DECL,
+        XML_INTERNAL_PARAMETER_ENTITY},
+        {"XML EXTERNAL PARAMETER ENTITY DECL",XML_ENTITY_DECL,
+         XML_EXTERNAL_PARAMETER_ENTITY},
+
         /*the line below must be the last one... */
         {NULL}
 };
-static const int ELEMENT_NODE = 0;
-static const int TEXT_NODE = 1;
-static const int PI_NODE = 2;
-static const int COMMENT_NODE = 3;
+/*the offset of the element types defined in gv_xml_node_types*/
+enum MlViewElementDescOffsets {
+        ELEMENT_NODE = 0,
+        TEXT_NODE,
+        PI_NODE,
+        COMMENT_NODE,
+        CDATA_SECTION_NODE,
+        INTERNAL_GENERAL_ENTITY_NODE,
+        EXTERNAL_GENERAL_PARSED_ENTITY_NODE,
+        EXTERNAL_GENERAL_UNPARSED_ENTITY_NODE,
+        INTERNAL_PARAMETER_ENTITY_NODE,
+        EXTERNAL_PARAMETER_ENTITY_NODE
+} ;
 
 /*
  *An index to find a node type def by the node type name. 
@@ -217,8 +230,7 @@ mlview_node_type_picker_init (MlViewNodeTypePicker * a_this)
         }
 
         /*init the private attributes */
-        PRIVATE (a_this)->selected_node_type =
-                NO_SELECTED_NODE_TYPE;
+        PRIVATE (a_this)->selected_node_type_def = NULL ;
 
         /*build the gui */
         PRIVATE (a_this)->node_types_combo =
@@ -234,6 +246,8 @@ mlview_node_type_picker_init (MlViewNodeTypePicker * a_this)
                  TRUE) ;
         PRIVATE (a_this)->node_name_or_content =
                 GTK_COMBO (gtk_combo_new ());
+        gtk_combo_disable_activate 
+                (PRIVATE (a_this)->node_name_or_content) ;
         gtk_entry_set_activates_default
                 (GTK_ENTRY 
                  (PRIVATE (a_this)->node_name_or_content->entry),
@@ -243,9 +257,8 @@ mlview_node_type_picker_init (MlViewNodeTypePicker * a_this)
         mlview_node_type_picker_init_node_type_list
                 (a_this);
 
-        PRIVATE (a_this)->selected_node_type =
-                gv_xml_node_types[0].node_type_id;
-
+        PRIVATE (a_this)->selected_node_type_def =
+                &gv_xml_node_types[ELEMENT_NODE] ;
         g_signal_connect
                 (G_OBJECT
                  (PRIVATE (a_this)->node_types_combo->entry), 
@@ -297,7 +310,7 @@ mlview_node_type_picker_init (MlViewNodeTypePicker * a_this)
 
 
 /**
- *mlview_node_type_picker_update_node_type_list_and_elements_list 
+ *
  *
  */
 static void
@@ -572,7 +585,8 @@ node_type_selected_cb (GtkEditable * a_entry,
         g_return_if_fail (node_type_def);
 
         mlview_node_type_picker_set_selected_node_type
-                (a_this, node_type_def->node_type_id);
+                (a_this, node_type_def->node_type, 
+                 node_type_def->entity_type);
 }
 
 
@@ -721,17 +735,16 @@ mlview_node_type_picker_set_title (MlViewNodeTypePicker *a_this,
 /**
  *Getter of the type of node selected by the user.
  *@param a_this the current instance of #MlViewNodeTypePicker.
- *@return the code of the node type selected by the user.
- *The returned code is of type enum xmlElementType defined in
- *the libxml2 library.
+ *@return a pointer to the #NodeTypeDefinition datastructure.
+ *Must *NOT* be freed by the caller !!!
  */
-guint 
+NodeTypeDefinition *
 mlview_node_type_picker_get_selected_node_type (MlViewNodeTypePicker * a_this) 
 {
-        g_return_val_if_fail (a_this != NULL, -1);
-        g_return_val_if_fail (PRIVATE (a_this) != NULL, -1);
+        g_return_val_if_fail (a_this != NULL, NULL);
+        g_return_val_if_fail (PRIVATE (a_this) != NULL, NULL);
 
-        return PRIVATE (a_this)->selected_node_type;
+        return PRIVATE (a_this)->selected_node_type_def ;
 }
 
 
@@ -779,17 +792,16 @@ mlview_node_type_picker_get_node_name_or_content (MlViewNodeTypePicker * a_this)
  *(must be of type enum xmlElementType defined in libxml2)
  */
 void
-mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_this, 
-                                                guint a_node_type) 
+mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_this,
+                                                xmlElementType a_node_type,
+                                                xmlEntityType a_entity_type/*in case a_node_type is an entity decl*/) 
 {
         g_return_if_fail (a_this != NULL);
-        g_return_if_fail (PRIVATE (a_this) != NULL);
+        g_return_if_fail (PRIVATE (a_this));
         g_return_if_fail (PRIVATE (a_this)->
                           node_name_or_content_label != NULL);
 
-        PRIVATE (a_this)->selected_node_type = a_node_type;
-
-        switch (PRIVATE (a_this)->selected_node_type) {
+        switch (a_node_type) {
         case XML_ELEMENT_NODE:
                 gtk_label_set_text 
                         (PRIVATE (a_this)->node_name_or_content_label,
@@ -803,13 +815,19 @@ mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_this,
                                  PRIVATE
                                  (a_this)->element_names_choice_list);
                 }
-
+                PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[ELEMENT_NODE] ;
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
                 break;
         case XML_COMMENT_NODE:
                 gtk_label_set_text 
                         (PRIVATE (a_this)->node_name_or_content_label,
                          _("Comment node content"));
-
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
                 if (PRIVATE (a_this)->node_name_or_content) {
                         gtk_list_clear_items
                                 (GTK_LIST
@@ -821,14 +839,20 @@ mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_this,
                                 (GTK_EDITABLE
                                  (PRIVATE (a_this)->node_name_or_content->entry),
                                  0, -1);
+                        
+                        gtk_widget_show 
+                                (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
                 }
+                PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[COMMENT_NODE];
                 break;
 
         case XML_TEXT_NODE:
                 gtk_label_set_text
                         (PRIVATE (a_this)->node_name_or_content_label,
                          _("Text node content"));
-
+                gtk_widget_hide
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
                 if (PRIVATE (a_this)->node_name_or_content) {
                         gtk_list_clear_items
                                 (GTK_LIST
@@ -840,15 +864,20 @@ mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_this,
                                  (PRIVATE
                                   (a_this)->node_name_or_content->entry), 0,
                                  -1);
+                        gtk_widget_hide 
+                                (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
                 }
+                PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[TEXT_NODE] ;
                 break;
 
-        case XML_PI_NODE:
+        case XML_PI_NODE:                
                 gtk_label_set_text
                         (PRIVATE 
                          (a_this)->node_name_or_content_label,
                          _("PI node name"));
-
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
                 if (PRIVATE (a_this)->node_name_or_content) {
                         gtk_list_clear_items
                                 (GTK_LIST
@@ -859,32 +888,107 @@ mlview_node_type_picker_set_selected_node_type (MlViewNodeTypePicker * a_this,
                                 (GTK_EDITABLE
                                  (PRIVATE (a_this)->node_name_or_content->entry),
                                  0, -1);
+                        gtk_widget_show
+                                (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
                 }
+                PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[PI_NODE] ;
                 break;
 
         case XML_CDATA_SECTION_NODE:
                 gtk_label_set_text
                         (PRIVATE (a_this)->node_name_or_content_label,
                          _("CDATA section node content"));
-
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
                 if (PRIVATE (a_this)->node_name_or_content) {
                         gtk_list_clear_items
                                 (GTK_LIST
                                  (PRIVATE (a_this)->
                                   node_name_or_content->list), 0,
                                  -1);
-                        gtk_editable_delete_text 
+                        gtk_editable_delete_text
                                 (GTK_EDITABLE
                                  (PRIVATE
                                   (a_this)->node_name_or_content->entry), 0,
                                  -1);
+                        gtk_widget_show 
+                                (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
                 }
+                PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[CDATA_SECTION_NODE] ;
                 break;
 
+        case XML_ENTITY_DECL:
+                switch (a_entity_type) {
+                case XML_INTERNAL_GENERAL_ENTITY:
+                        gtk_label_set_text
+                                (PRIVATE (a_this)->node_name_or_content_label,
+                                 _("INTERNAL GENERAL ENTITY node name"));
+                        PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[INTERNAL_GENERAL_ENTITY_NODE] ;
+                        break ;
+                case XML_EXTERNAL_GENERAL_PARSED_ENTITY:
+                        gtk_label_set_text
+                                (PRIVATE (a_this)->node_name_or_content_label,
+                                 _("EXTERNAL GENERAL PARSED ENTITY node name"));
+                        PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[EXTERNAL_GENERAL_PARSED_ENTITY_NODE] ;
+                        break ;
+                case XML_EXTERNAL_GENERAL_UNPARSED_ENTITY:
+                        gtk_label_set_text
+                                (PRIVATE (a_this)->node_name_or_content_label,
+                                 _("EXTERNAL GENERAL UNPARSED ENTITY node name"));
+                        PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[EXTERNAL_GENERAL_UNPARSED_ENTITY_NODE] ;
+                        break ;
+                case XML_INTERNAL_PARAMETER_ENTITY:
+                        gtk_label_set_text
+                                (PRIVATE (a_this)->node_name_or_content_label,
+                                 _("INTERNAL PARAMETER ENTITY node name"));
+                        PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[INTERNAL_PARAMETER_ENTITY_NODE] ;
+                        break ;
+                case XML_EXTERNAL_PARAMETER_ENTITY:
+                        gtk_label_set_text
+                                (PRIVATE (a_this)->node_name_or_content_label,
+                                 _("EXTERNAL PARAMETER ENTITY node name"));
+                        PRIVATE (a_this)->selected_node_type_def = 
+                        &gv_xml_node_types[EXTERNAL_PARAMETER_ENTITY_NODE] ;
+                        break ;
+                default:
+                        mlview_utils_trace_info 
+                                ("should not reach this case") ;
+                        break ;
+                }
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
+                if (PRIVATE (a_this)->node_name_or_content) {
+                        gtk_list_clear_items
+                                (GTK_LIST
+                                 (PRIVATE (a_this)->
+                                  node_name_or_content->list), 0,
+                                 -1);
+                        gtk_editable_delete_text
+                                (GTK_EDITABLE
+                                 (PRIVATE
+                                  (a_this)->node_name_or_content->entry), 0,
+                                 -1);
+                        gtk_widget_show 
+                                (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
+                }
+                break ;
         default:
                 gtk_label_set_text
                         (PRIVATE (a_this)->node_name_or_content_label,
                          _("Element node name"));
+                gtk_widget_show 
+                        (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content_label));
+                PRIVATE (a_this)->selected_node_type_def = NULL ;
+                if (PRIVATE (a_this)->node_name_or_content) {
+                        gtk_widget_show 
+                                (GTK_WIDGET (PRIVATE (a_this)->node_name_or_content));
+                }
                 break;
         }
 }
